@@ -135,9 +135,9 @@ foreach ($data['data']['problems'] as $eventid => $problem) {
 	if ($problem['r_eventid'] != 0) {
 		if ($problem['correlationid'] != 0) {
 			$info_icons[] = makeInformationIcon(
-				array_key_exists($problem['correlationid'], $data['correlations'])
+				array_key_exists($problem['correlationid'], $data['data']['correlations'])
 					? _s('Resolved by correlation rule "%1$s".',
-						$data['correlations'][$problem['correlationid']]['name']
+						$data['data']['correlations'][$problem['correlationid']]['name']
 					)
 					: _('Resolved by correlation rule.')
 			);
