@@ -48,8 +48,6 @@ class CApplication extends CApiService {
 	 */
 	public function get($options = []) {
 		$result = [];
-		$userType = self::$userData['type'];
-		$userid = self::$userData['userid'];
 
 		$sqlParts = [
 			'select'	=> ['apps' => 'a.applicationid'],
@@ -67,7 +65,7 @@ class CApplication extends CApiService {
 			'itemids'						=> null,
 			'applicationids'				=> null,
 			'templated'						=> null,
-			'editable'						=> null,
+			'editable'						=> false,
 			'inherited'						=> null,
 			'nopermissions'					=> null,
 			// filter
@@ -93,10 +91,9 @@ class CApplication extends CApiService {
 		$options = zbx_array_merge($defOptions, $options);
 
 		// editable + PERMISSION CHECK
-		if ($userType != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
+		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
 			$permission = $options['editable'] ? PERM_READ_WRITE : PERM_READ;
-
-			$userGroups = getUserGroupsByUserId($userid);
+			$userGroups = getUserGroupsByUserId(self::$userData['userid']);
 
 			$sqlParts['where'][] = 'EXISTS ('.
 					'SELECT NULL'.
