@@ -43,8 +43,6 @@ class CDiscoveryRule extends CItemGeneral {
 	 */
 	public function get($options = []) {
 		$result = [];
-		$userType = self::$userData['type'];
-		$userid = self::$userData['userid'];
 
 		$sqlParts = [
 			'select'	=> ['items' => 'i.itemid'],
@@ -64,7 +62,7 @@ class CDiscoveryRule extends CItemGeneral {
 			'inherited'					=> null,
 			'templated'					=> null,
 			'monitored'					=> null,
-			'editable'					=> null,
+			'editable'					=> false,
 			'nopermissions'				=> null,
 			// filter
 			'filter'					=> null,
@@ -92,10 +90,9 @@ class CDiscoveryRule extends CItemGeneral {
 		$options = zbx_array_merge($defOptions, $options);
 
 		// editable + PERMISSION CHECK
-		if ($userType != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
+		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
 			$permission = $options['editable'] ? PERM_READ_WRITE : PERM_READ;
-
-			$userGroups = getUserGroupsByUserId($userid);
+			$userGroups = getUserGroupsByUserId(self::$userData['userid']);
 
 			$sqlParts['where'][] = 'EXISTS ('.
 				'SELECT NULL'.
@@ -420,6 +417,16 @@ class CDiscoveryRule extends CItemGeneral {
 		// delete LLD rules
 		DB::delete('items', ['itemid' => $ruleids]);
 
+		$insert = [];
+		foreach ($ruleids as $ruleid) {
+			$insert[] = [
+				'tablename' => 'events',
+				'field' => 'lldruleid',
+				'value' => $ruleid
+			];
+		}
+		DB::insertBatch('housekeeper', $insert);
+
 		// TODO: remove info from API
 		foreach ($delRules as $item) {
 			$host = reset($item['hosts']);
