@@ -65,7 +65,7 @@ class CScreenItem extends CApiService {
 		$this->getOptions = zbx_array_merge($this->getOptions, [
 			'screenitemids'	=> null,
 			'screenids'		=> null,
-			'editable'		=> null,
+			'editable'		=> false,
 			'sortfield'		=> '',
 			'sortorder'		=> '',
 			'preservekeys'	=> false,
@@ -159,6 +159,8 @@ class CScreenItem extends CApiService {
 		}
 		unset($screenItem);
 
+		$this->validateItemsURL($screenItems);
+
 		$screenIds = array_keys(array_flip(zbx_objectValues($screenItems, 'screenid')));
 
 		$dbScreens = API::Screen()->get([
@@ -270,6 +272,8 @@ class CScreenItem extends CApiService {
 			}
 		}
 
+		$this->validateItemsURL($screenItems);
+
 		$screenItems = zbx_toHash($screenItems, 'screenitemid');
 		$screenItemIds = array_keys($screenItems);
 
@@ -948,4 +952,20 @@ class CScreenItem extends CApiService {
 	protected function isValidMaxColumns($maxColumns) {
 		return ($maxColumns >= SCREEN_SURROGATE_MAX_COLUMNS_MIN && $maxColumns <= SCREEN_SURROGATE_MAX_COLUMNS_MAX);
 	}
+
+	/**
+	 * Validates URL fields for submitted screen items.
+	 *
+	 * @throws APIException for invalid URL
+	 *
+	 * @param array $screen_items	Array of screen items.
+	 */
+	protected function validateItemsURL($screen_items) {
+		foreach ($screen_items as $screen_item) {
+			if ($screen_item['resourcetype'] == SCREEN_RESOURCE_URL && array_key_exists('url', $screen_item)
+					&& !CHtmlUrlValidator::validate($screen_item['url'])) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _('Wrong value for url field.'));
+			}
+		}
+	}
 }
