@@ -93,11 +93,16 @@ function addScreenRow(array $screen, $row_num) {
 	unset($screen_item);
 
 	DBstart();
-	$result = API::Screen()->update([
+	$options = [
 		'screenid' => $screen['screenid'],
 		'vsize' => $screen['vsize'] + 1,
 		'screenitems' => $screen['screenitems']
-	]);
+	];
+
+	$result = ($screen['templateid'] != 0)
+		? API::TemplateScreen()->update($options)
+		: API::Screen()->update($options);
+
 	if ($result) {
 		add_audit_details(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_SCREEN, $screen['screenid'], $screen['name'],
 			_('Row added')
@@ -121,11 +126,16 @@ function addScreenColumn(array $screen, $col_num) {
 	unset($screen_item);
 
 	DBstart();
-	$result = API::Screen()->update([
+	$options = [
 		'screenid' => $screen['screenid'],
 		'hsize' => $screen['hsize'] + 1,
 		'screenitems' => $screen['screenitems']
-	]);
+	];
+
+	$result = ($screen['templateid'] != 0)
+		? API::TemplateScreen()->update($options)
+		: API::Screen()->update($options);
+
 	if ($result) {
 		add_audit_details(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_SCREEN, $screen['screenid'], $screen['name'],
 			_('Column added')
@@ -152,11 +162,16 @@ function delScreenRow(array $screen, $row_num) {
 	unset($screen_item);
 
 	DBstart();
-	$result = API::Screen()->update([
+	$options = [
 		'screenid' => $screen['screenid'],
 		'vsize' => $screen['vsize'] - 1,
 		'screenitems' => $screen['screenitems']
-	]);
+	];
+
+	$result = ($screen['templateid'] != 0)
+		? API::TemplateScreen()->update($options)
+		: API::Screen()->update($options);
+
 	if ($result) {
 		add_audit_details(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_SCREEN, $screen['screenid'], $screen['name'],
 			_('Row deleted')
@@ -183,11 +198,16 @@ function delScreenColumn(array $screen, $col_num) {
 	unset($screen_item);
 
 	DBstart();
-	$result = API::Screen()->update([
+	$options = [
 		'screenid' => $screen['screenid'],
 		'hsize' => $screen['hsize'] - 1,
 		'screenitems' => $screen['screenitems']
-	]);
+	];
+
+	$result = ($screen['templateid'] != 0)
+		? API::TemplateScreen()->update($options)
+		: API::Screen()->update($options);
+
 	if ($result) {
 		add_audit_details(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_SCREEN, $screen['screenid'], $screen['name'],
 			_('Column deleted')
@@ -297,6 +317,12 @@ function get_slideshow_by_slideshowid($slideshowid, $permission) {
 function add_slideshow($data) {
 	$user_data = CWebUser::$data;
 
+	if (!validateTimeUnit($data['delay'], 1, SEC_PER_DAY, false, $error)) {
+		error(_s('Incorrect value for field "%1$s": %2$s.', 'delay', $error));
+
+		return false;
+	}
+
 	// Validate slides.
 	if (empty($data['slides'])) {
 		error(_('Slide show must contain slides.'));
@@ -304,6 +330,14 @@ function add_slideshow($data) {
 		return false;
 	}
 
+	foreach ($data['slides'] as $slide) {
+		if (!validateTimeUnit($slide['delay'], 0, SEC_PER_DAY, false, $error)) {
+			error(_s('Incorrect value for field "%1$s": %2$s.', 'delay', $error));
+
+			return false;
+		}
+	}
+
 	// Validate screens.
 	$screenids = zbx_objectValues($data['slides'], 'screenid');
 
@@ -396,11 +430,6 @@ function add_slideshow($data) {
 	foreach ($data['slides'] as $slide) {
 		$slideid = get_dbid('slides', 'slideid');
 
-		// set default delay
-		if (empty($slide['delay'])) {
-			$slide['delay'] = 0;
-		}
-
 		$result = DBexecute(
 			'INSERT INTO slides (slideid,slideshowid,screenid,step,delay)'.
 			' VALUES ('.zbx_dbstr($slideid).','.zbx_dbstr($slideshowid).','.zbx_dbstr($slide['screenid']).','.($i++).','.zbx_dbstr($slide['delay']).')'
@@ -417,6 +446,12 @@ function add_slideshow($data) {
 function update_slideshow($data) {
 	$user_data = CWebUser::$data;
 
+	if (!validateTimeUnit($data['delay'], 1, SEC_PER_DAY, false, $error)) {
+		error(_s('Incorrect value for field "%1$s": %2$s.', 'delay', $error));
+
+		return false;
+	}
+
 	// Validate slides.
 	if (empty($data['slides'])) {
 		error(_('Slide show must contain slides.'));
@@ -424,6 +459,14 @@ function update_slideshow($data) {
 		return false;
 	}
 
+	foreach ($data['slides'] as $slide) {
+		if (!validateTimeUnit($slide['delay'], 0, SEC_PER_DAY, false, $error)) {
+			error(_s('Incorrect value for field "%1$s": %2$s.', 'delay', $error));
+
+			return false;
+		}
+	}
+
 	// validate screens.
 	$screenids = zbx_objectValues($data['slides'], 'screenid');
 
@@ -605,7 +648,6 @@ function update_slideshow($data) {
 	$slidesToDel = zbx_toHash($slidesToDel);
 	$step = 0;
 	foreach ($data['slides'] as $slide) {
-		$slide['delay'] = $slide['delay'] ? $slide['delay'] : 0;
 		if (isset($db_slides[$slide['slideid']])) {
 			// update slide
 			if ($db_slides[$slide['slideid']]['delay'] != $slide['delay'] || $db_slides[$slide['slideid']]['step'] != $step) {
