@@ -380,8 +380,7 @@ elseif (in_array($resourceType, [SCREEN_RESOURCE_HOSTGROUP_TRIGGERS, SCREEN_RESO
 		if ($resourceId > 0) {
 			$data = API::HostGroup()->get([
 				'groupids' => $resourceId,
-				'output' => ['groupid', 'name'],
-				'editable' => true
+				'output' => ['groupid', 'name']
 			]);
 
 			if ($data) {
@@ -393,7 +392,6 @@ elseif (in_array($resourceType, [SCREEN_RESOURCE_HOSTGROUP_TRIGGERS, SCREEN_RESO
 			(new CMultiSelect([
 				'name' => 'resourceid',
 				'objectName' => 'hostGroup',
-				'objectOptions' => ['editable' => true],
 				'data' => $data ? [['id' => $data['groupid'], 'name' => $data['name']]] : null,
 				'defaultValue' => 0,
 				'selectedLimit' => 1,
@@ -408,8 +406,7 @@ elseif (in_array($resourceType, [SCREEN_RESOURCE_HOSTGROUP_TRIGGERS, SCREEN_RESO
 		if ($resourceId > 0) {
 			$data = API::Host()->get([
 				'hostids' => $resourceId,
-				'output' => ['hostid', 'name'],
-				'editable' => true
+				'output' => ['hostid', 'name']
 			]);
 
 			if ($data) {
@@ -421,7 +418,6 @@ elseif (in_array($resourceType, [SCREEN_RESOURCE_HOSTGROUP_TRIGGERS, SCREEN_RESO
 			(new CMultiSelect([
 				'name' => 'resourceid',
 				'objectName' => 'hosts',
-				'objectOptions' => ['editable' => true],
 				'data' => $data ? [['id' => $data['hostid'], 'name' => $data['name']]] : null,
 				'defaultValue' => 0,
 				'selectedLimit' => 1,
@@ -487,8 +483,7 @@ elseif (in_array($resourceType, [SCREEN_RESOURCE_TRIGGER_OVERVIEW, SCREEN_RESOUR
 	if ($resourceId > 0) {
 		$data = API::HostGroup()->get([
 			'groupids' => $resourceId,
-			'output' => ['groupid', 'name'],
-			'editable' => true
+			'output' => ['groupid', 'name']
 		]);
 
 		if ($data) {
@@ -500,7 +495,6 @@ elseif (in_array($resourceType, [SCREEN_RESOURCE_TRIGGER_OVERVIEW, SCREEN_RESOUR
 		(new CMultiSelect([
 			'name' => 'resourceid',
 			'objectName' => 'hostGroup',
-			'objectOptions' => ['editable' => true],
 			'data' => $data ? [['id' => $data['groupid'], 'name' => $data['name']]] : null,
 			'selectedLimit' => 1,
 			'popup' => [
@@ -560,8 +554,7 @@ elseif ($resourceType == SCREEN_RESOURCE_HOST_INFO || $resourceType == SCREEN_RE
 	if ($resourceId > 0) {
 		$data = API::HostGroup()->get([
 			'groupids' => $resourceId,
-			'output' => ['groupid', 'name'],
-			'editable' => true
+			'output' => ['groupid', 'name']
 		]);
 
 		if ($data) {
@@ -573,7 +566,6 @@ elseif ($resourceType == SCREEN_RESOURCE_HOST_INFO || $resourceType == SCREEN_RE
 		(new CMultiSelect([
 			'name' => 'resourceid',
 			'objectName' => 'hostGroup',
-			'objectOptions' => ['editable' => true],
 			'data' => $data ? [['id' => $data['groupid'], 'name' => $data['name']]] : null,
 			'defaultValue' => 0,
 			'selectedLimit' => 1,
