@@ -79,10 +79,10 @@ if (isset($_REQUEST['enter']) && $_REQUEST['enter'] == _('Sign in')) {
 		$request = getRequest('request', '');
 
 		if ($request) {
-			preg_match('/^\/?(?<filename>(?:[a-z0-9\_\.]+)\.php).*$/i', $request, $test_request);
+			preg_match('/^\/?(?<filename>[a-z0-9\_\.]+\.php)(?<request>\?.*)?$/i', $request, $test_request);
 
 			$request = (array_key_exists('filename', $test_request) && file_exists('./'.$test_request['filename']))
-				? $test_request['filename']
+				? $test_request['filename'].(array_key_exists('request', $test_request) ? $test_request['request'] : '')
 				: '';
 		}
 
